<?php

namespace Litecms\TestPackage\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\TestPackage\Http\Requests\TestPackageRequest;
use Litecms\TestPackage\Interfaces\TestPackageRepositoryInterface;
use Litecms\TestPackage\Models\TestPackage;

/**
 * Resource controller class for test_package.
 */
class TestPackageResourceController extends BaseController
{

    /**
     * Initialize test_package resource controller.
     *
     * @param type TestPackageRepositoryInterface $test_package
     *
     * @return null
     */
    public function __construct(TestPackageRepositoryInterface $test_package)
    {
        parent::__construct();
        $this->repository = $test_package;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\TestPackage\Repositories\Criteria\TestPackageResourceCriteria::class);
    }

    /**
     * Display a list of test_package.
     *
     * @return Response
     */
    public function index(TestPackageRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\TestPackage\Repositories\Presenter\TestPackagePresenter::class)
                ->$function();
        }

        $test_packages = $this->repository->paginate();

        return $this->response->title(trans('test_package::test_package.names'))
            ->view('test_package::test_package.index', true)
            ->data(compact('test_packages'))
            ->output();
    }

    /**
     * Display test_package.
     *
     * @param Request $request
     * @param Model   $test_package
     *
     * @return Response
     */
    public function show(TestPackageRequest $request, TestPackage $test_package)
    {

        if ($test_package->exists) {
            $view = 'test_package::test_package.show';
        } else {
            $view = 'test_package::test_package.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('test_package::test_package.name'))
            ->data(compact('test_package'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new test_package.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TestPackageRequest $request)
    {

        $test_package = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('test_package::test_package.name')) 
            ->view('test_package::test_package.create', true) 
            ->data(compact('test_package'))
            ->output();
    }

    /**
     * Create new test_package.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TestPackageRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $test_package                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('test_package::test_package.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('test_package/test_package/' . $test_package->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/test_package/test_package'))
                ->redirect();
        }

    }

    /**
     * Show test_package for editing.
     *
     * @param Request $request
     * @param Model   $test_package
     *
     * @return Response
     */
    public function edit(TestPackageRequest $request, TestPackage $test_package)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('test_package::test_package.name'))
            ->view('test_package::test_package.edit', true)
            ->data(compact('test_package'))
            ->output();
    }

    /**
     * Update the test_package.
     *
     * @param Request $request
     * @param Model   $test_package
     *
     * @return Response
     */
    public function update(TestPackageRequest $request, TestPackage $test_package)
    {
        try {
            $attributes = $request->all();

            $test_package->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('test_package::test_package.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('test_package/test_package/' . $test_package->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('test_package/test_package/' . $test_package->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the test_package.
     *
     * @param Model   $test_package
     *
     * @return Response
     */
    public function destroy(TestPackageRequest $request, TestPackage $test_package)
    {
        try {

            $test_package->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('test_package::test_package.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('test_package/test_package/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('test_package/test_package/' . $test_package->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple test_package.
     *
     * @param Model   $test_package
     *
     * @return Response
     */
    public function delete(TestPackageRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('test_package::test_package.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('test_package/test_package'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/test_package/test_package'))
                ->redirect();
        }

    }

    /**
     * Restore deleted test_packages.
     *
     * @param Model   $test_package
     *
     * @return Response
     */
    public function restore(TestPackageRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('test_package::test_package.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/test_package/test_package'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/test_package/test_package/'))
                ->redirect();
        }

    }

}
